@@ -1104,11 +1104,9 @@ trash_retrieve_files_to_restore_thread (GSimpleAsyncResult *res,
 		GFileInfo *info;
 		gpointer lookupvalue;
 		GFile *item;
-		GTimeVal timeval;
 		glong trash_time, orig_trash_time;
 		const char *origpath;
 		GFile *origfile;
-		const char *time_string;
 
 		while ((info = g_file_enumerator_next_file (enumerator, NULL, &error)) != NULL) {
 			/* Retrieve the original file uri */
@@ -1118,13 +1116,14 @@ trash_retrieve_files_to_restore_thread (GSimpleAsyncResult *res,
 			lookupvalue = g_hash_table_lookup (self->priv->trashed, origfile);
 
 			if (lookupvalue) {
+				GDateTime *date;
+
 				orig_trash_time = GPOINTER_TO_SIZE (lookupvalue);
-				time_string = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_TRASH_DELETION_DATE);
-				if (time_string != NULL) {
-					g_time_val_from_iso8601 (time_string, &timeval);
-					trash_time = timeval.tv_sec;
-				} else {
-					trash_time = 0;
+				trash_time = 0;
+				date = g_file_info_get_deletion_date (info);
+				if (date) {
+					trash_time = g_date_time_to_unix (date);
+					g_date_time_unref (date);
 				}
 
 				if (trash_time == orig_trash_time) {
