@@ -194,21 +194,12 @@ nautilus_ui_frame_image (GdkPixbuf **pixbuf)
 {
 	GdkPixbuf *pixbuf_with_frame, *frame;
 	int left_offset, top_offset, right_offset, bottom_offset;
-	int size;
 
 	frame = nautilus_get_thumbnail_frame ();
 	if (frame == NULL) {
 		return;
 	}
 
-	size = MAX (gdk_pixbuf_get_width (*pixbuf),
-		    gdk_pixbuf_get_height (*pixbuf));
-
-	/* We don't want frames around small icons */
-	if (size < 128 && gdk_pixbuf_get_has_alpha (*pixbuf)) {
-		return;
-	}
-
 	left_offset = NAUTILUS_THUMBNAIL_FRAME_LEFT;
 	top_offset = NAUTILUS_THUMBNAIL_FRAME_TOP;
 	right_offset = NAUTILUS_THUMBNAIL_FRAME_RIGHT;
