@@ -47,7 +47,7 @@ sendto_callback (NautilusMenuItem *item,
 		NautilusFileInfo *file = scan->data;
 
 		uri = nautilus_file_info_get_uri (file);
-		g_string_append_printf (cmd, " “%s”", uri);
+		g_string_append_printf (cmd, " \"%s\"", uri);
 		g_free (uri);
 	}
 
@@ -77,13 +77,13 @@ nautilus_nste_get_file_items (NautilusMenuProvider *provider,
 	if (one_item &&
 	    !nautilus_file_info_is_directory ((NautilusFileInfo *)files->data)) {
 		item = nautilus_menu_item_new ("NautilusNste::sendto",
-					       _("Send To..."),
-					       _("Send file by mail, instant message..."),
+					       _("Send To…"),
+					       _("Send file by mail, instant message…"),
 					       "document-send");
 	} else {
 		item = nautilus_menu_item_new ("NautilusNste::sendto",
-					       _("Send To..."),
-					       _("Send files by mail, instant message..."),
+					       _("Send To…"),
+					       _("Send files by mail, instant message…"),
 					       "document-send");
 	}
 	g_signal_connect (item,
