@@ -593,7 +593,7 @@ file_open_callback (GObject      *object,
 		g_free (mime_type);
 
 		g_signal_connect (page->details->loader,
-				  "size_prepared",
+				  "size-prepared",
 				  G_CALLBACK (size_prepared_callback),
 				  page);
 
@@ -706,7 +706,7 @@ nautilus_image_properties_page_init (NautilusImagePropertiesPage *page)
 	gtk_grid_set_row_spacing (GTK_GRID (page->details->grid), 6);
 	gtk_grid_set_column_spacing (GTK_GRID (page->details->grid), 20);
 	append_item (page, _("Loading…"), NULL);
-	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw), page->details->grid);
+	gtk_container_add (GTK_CONTAINER (sw), page->details->grid);
 
 	gtk_widget_show_all (GTK_WIDGET (page));
 }
