@@ -69,7 +69,6 @@ struct NautilusQueryEditorDetails {
 	char *current_uri;
 
 	GList *rows;
-	gboolean got_preedit;
 
 	NautilusQuery *query;
 };
@@ -109,89 +108,14 @@ static NautilusQueryEditorRowOps row_type[] = {
 
 G_DEFINE_TYPE (NautilusQueryEditor, nautilus_query_editor, GTK_TYPE_BOX);
 
-/* taken from gtk/gtktreeview.c */
-static void
-send_focus_change (GtkWidget *widget,
-                   GdkDevice *device,
-		   gboolean   in)
-{
-	GdkDeviceManager *device_manager;
-	GList *devices, *d;
-
-	device_manager = gdk_display_get_device_manager (gtk_widget_get_display (widget));
-	devices = gdk_device_manager_list_devices (device_manager, GDK_DEVICE_TYPE_MASTER);
-	devices = g_list_concat (devices, gdk_device_manager_list_devices (device_manager, GDK_DEVICE_TYPE_SLAVE));
-	devices = g_list_concat (devices, gdk_device_manager_list_devices (device_manager, GDK_DEVICE_TYPE_FLOATING));
-
-	for (d = devices; d; d = d->next) {
-		GdkDevice *dev = d->data;
-		GdkEvent *fevent;
-		GdkWindow *window;
-
-		if (gdk_device_get_source (dev) != GDK_SOURCE_KEYBOARD)
-			continue;
-
-		window = gtk_widget_get_window (widget);
-
-		/* Skip non-master keyboards that haven't
-		 * selected for events from this window
-		 */
-		if (gdk_device_get_device_type (dev) != GDK_DEVICE_TYPE_MASTER &&
-		    !gdk_window_get_device_events (window, dev))
-			continue;
-
-		fevent = gdk_event_new (GDK_FOCUS_CHANGE);
-
-		fevent->focus_change.type = GDK_FOCUS_CHANGE;
-		fevent->focus_change.window = g_object_ref (window);
-		fevent->focus_change.in = in;
-		gdk_event_set_device (fevent, device);
-
-		gtk_widget_send_focus_change (widget, fevent);
-
-		gdk_event_free (fevent);
-	}
-
-	g_list_free (devices);
-}
-
-static void
-entry_focus_hack (GtkWidget *entry,
-		  GdkDevice *device)
-{
-	GtkEntryClass *entry_class;
-	GtkWidgetClass *entry_parent_class;
-
-	/* Grab focus will select all the text.  We don't want that to happen, so we
-	 * call the parent instance and bypass the selection change.  This is probably
-	 * really non-kosher. */
-	entry_class = g_type_class_peek (GTK_TYPE_ENTRY);
-	entry_parent_class = g_type_class_peek_parent (entry_class);
-	(entry_parent_class->grab_focus) (entry);
-
-	/* send focus-in event */
-	send_focus_change (entry, device, TRUE);
-}
-
-static void
-entry_preedit_changed_cb (GtkEntry            *entry,
-			  gchar               *preedit,
-			  NautilusQueryEditor *editor)
-{
-	editor->details->got_preedit = TRUE;
-}
-
 gboolean
 nautilus_query_editor_handle_event (NautilusQueryEditor *editor,
 				    GdkEventKey         *event)
 {
+	GtkWidget *toplevel;
+	GtkWidget *old_focus;
 	GdkEvent *new_event;
-	gboolean handled = FALSE;
-	gulong id;
 	gboolean retval;
-	gboolean text_changed;
-	char *old_text;
-	const char *new_text;
 
 	/* if we're focused already, no need to handle the event manually */
 	if (gtk_widget_has_focus (editor->details->entry)) {
@@ -208,15 +132,24 @@ nautilus_query_editor_handle_event (NautilusQueryEditor *editor,
 		return FALSE;
 	}
 
-	editor->details->got_preedit = FALSE;
+	/* if it's not printable we don't need it */
+	if (!g_unichar_isprint (gdk_keyval_to_unicode (event->keyval))) {
+		return FALSE;
+	}
+
 	if (!gtk_widget_get_realized (editor->details->entry)) {
 		gtk_widget_realize (editor->details->entry);
 	}
 
-	old_text = g_strdup (gtk_entry_get_text (GTK_ENTRY (editor->details->entry)));
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (editor));
+	if (gtk_widget_is_toplevel (toplevel)) {
+		old_focus = gtk_window_get_focus (GTK_WINDOW (toplevel));
+	} else {
+		old_focus = NULL;
+	}
 
-	id = g_signal_connect (editor->details->entry, "preedit-changed",
-			       G_CALLBACK (entry_preedit_changed_cb), editor);
+	/* input methods will typically only process events after getting focus */
+	gtk_widget_grab_focus (editor->details->entry);
 
 	new_event = gdk_event_copy ((GdkEvent *) event);
 	g_object_unref (((GdkEventKey *) new_event)->window);
@@ -225,16 +158,11 @@ nautilus_query_editor_handle_event (NautilusQueryEditor *editor,
 	retval = gtk_widget_event (editor->details->entry, new_event);
 	gdk_event_free (new_event);
 
-	g_signal_handler_disconnect (editor->details->entry, id);
+	if (!retval && old_focus) {
+		gtk_widget_grab_focus (old_focus);
+	}
 
-	new_text = gtk_entry_get_text (GTK_ENTRY (editor->details->entry));
-	text_changed = strcmp (old_text, new_text) != 0;
-	g_free (old_text);
-
-	handled = (editor->details->got_preedit) || (retval && text_changed);
-	editor->details->got_preedit = FALSE;
-
-	return handled;
+	return retval;
 }
 
 static void
@@ -270,7 +198,9 @@ nautilus_query_editor_grab_focus (GtkWidget *widget)
 	NautilusQueryEditor *editor = NAUTILUS_QUERY_EDITOR (widget);
 
 	if (gtk_widget_get_visible (widget)) {
-		entry_focus_hack (editor->details->entry, gtk_get_current_event_device ());
+		/* avoid selecting the entry text */
+		gtk_widget_grab_focus (editor->details->entry);
+		gtk_editable_set_position (GTK_EDITABLE (editor->details->entry), -1);
 	}
 }
 
@@ -1210,6 +1140,7 @@ nautilus_query_editor_set_query (NautilusQueryEditor	*editor,
 				 NautilusQuery		*query)
 {
 	char *text = NULL;
+	char *current_text = NULL;
 
 	if (query != NULL) {
 		text = nautilus_query_get_text (query);
@@ -1220,7 +1151,12 @@ nautilus_query_editor_set_query (NautilusQueryEditor	*editor,
 	}
 
 	editor->details->change_frozen = TRUE;
-	gtk_entry_set_text (GTK_ENTRY (editor->details->entry), text);
+
+	current_text = g_strstrip (g_strdup (gtk_entry_get_text (GTK_ENTRY (editor->details->entry))));
+	if (!g_str_equal (current_text, text)) {
+		gtk_entry_set_text (GTK_ENTRY (editor->details->entry), text);
+	}
+	g_free (current_text);
 
 	g_free (editor->details->current_uri);
 	editor->details->current_uri = NULL;
